require 'spec_helper'

describe HTH::RestUserManager do

  let(:source) { 'example_ldap' }

  before do
    @rest = HTH::RestUserManager.new(source: source)
  end

  context "#request_count" do
    [
      {total: 100, limit: 100, expected: 1},
      {total: 101, limit: 100, expected: 2},
      {total: 0,   limit: 100, expected: 0},
      {total: 99,  limit: 100, expected: 1},
      {total: 199, limit: 50,  expected: 4},
      {total: 200, limit: 50,  expected: 4},
      {total: 200, limit: 300, expected: 1},
    ].each do |hash|
      it "should take #{hash[:expected]} requests when there are #{hash[:total]} users and the max limit is #{hash[:limit]}" do
        @rest.send(:request_count, hash[:total], hash[:limit]).should == hash[:expected]
      end
    end
  end

  context "#find_all" do
    before do
      @rest.stubs(:user_count).returns({
        content: { count: 1001 }
      })
      @rest.stubs(:handle_request).returns({
        status: 200,
        content: {
          results: []
        }
      })
    end

    it "requests active and inactive users from a specified source" do
      @rest.expects(:uri).with("users?limit=500&offset=0&active=true,false&source=#{source}").once
      @rest.expects(:uri).with("users?limit=500&offset=500&active=true,false&source=#{source}").once
      @rest.expects(:uri).with("users?limit=500&offset=1000&active=true,false&source=#{source}").once
      @rest.find_all
    end

    it "requests only active users from a specified source" do
      @rest.expects(:uri).with("users?limit=500&offset=0&active=true&source=#{source}").once
      @rest.expects(:uri).with("users?limit=500&offset=500&active=true&source=#{source}").once
      @rest.expects(:uri).with("users?limit=500&offset=1000&active=true&source=#{source}").once
      @rest.find_all(only_active: true)
    end
  end
end
